summaryrefslogtreecommitdiffstats
path: root/testing/talos
diff options
context:
space:
mode:
Diffstat (limited to 'testing/talos')
-rw-r--r--testing/talos/perfdocs/index.rst4
-rw-r--r--testing/talos/talos/config.py6
-rw-r--r--testing/talos/talos/gecko_profile.py2
-rw-r--r--testing/talos/talos/test.py1
-rw-r--r--testing/talos/talos/unittests/test_config.py4
5 files changed, 9 insertions, 8 deletions
diff --git a/testing/talos/perfdocs/index.rst b/testing/talos/perfdocs/index.rst
index e5e4ebe2a5..e1a2f150f0 100644
--- a/testing/talos/perfdocs/index.rst
+++ b/testing/talos/perfdocs/index.rst
@@ -125,7 +125,7 @@ At a glance
- Tests are defined in
`testing/talos/talos/test.py <https://searchfox.org/mozilla-central/source/testing/talos/talos/test.py>`__
- Treeherder abbreviations are defined in
- `taskcluster/ci/test/talos.yml <https://searchfox.org/mozilla-central/source/taskcluster/ci/test/talos.yml>`__
+ `taskcluster/kinds/test/talos.yml <https://searchfox.org/mozilla-central/source/taskcluster/kinds/test/talos.yml>`__
- Suites are defined for production in
`testing/talos/talos.json <https://searchfox.org/mozilla-central/source/testing/talos/talos.json>`__
@@ -133,7 +133,7 @@ Test lifecycle
**************
- Taskcluster schedules `talos
- jobs <https://searchfox.org/mozilla-central/source/taskcluster/ci/test/talos.yml>`__
+ jobs <https://searchfox.org/mozilla-central/source/taskcluster/kinds/test/talos.yml>`__
- Taskcluster runs a Talos job on a hardware machine when one is
available - this is bootstrapped by
`mozharness <https://searchfox.org/mozilla-central/source/testing/mozharness/mozharness/mozilla/testing/talos.py>`__
diff --git a/testing/talos/talos/gecko_profile.py b/testing/talos/talos/gecko_profile.py
index f7bbbaf597..0707aff6ca 100644
--- a/testing/talos/talos/gecko_profile.py
+++ b/testing/talos/talos/gecko_profile.py
@@ -42,7 +42,7 @@ class GeckoProfile(object):
"gecko_profile_entries", int(128 * 1024 * 1024 / 8)
)
gecko_profile_features = test_config.get(
- "gecko_profile_features", "js,stackwalk,cpu,screenshots"
+ "gecko_profile_features", "js,stackwalk,cpu,screenshots,memory"
)
gecko_profile_threads = test_config.get(
"gecko_profile_threads", "GeckoMain,Compositor,Renderer"
diff --git a/testing/talos/talos/test.py b/testing/talos/talos/test.py
index f64d5004ef..18b01aeb2a 100644
--- a/testing/talos/talos/test.py
+++ b/testing/talos/talos/test.py
@@ -424,6 +424,7 @@ class pdfpaint(PageloaderTest):
tptimeout = 60000
pdfpaint = True
unit = "ms"
+ subtest_alerts = True
@register_test()
diff --git a/testing/talos/talos/unittests/test_config.py b/testing/talos/talos/unittests/test_config.py
index d5e1b5eebc..90f92e2d17 100644
--- a/testing/talos/talos/unittests/test_config.py
+++ b/testing/talos/talos/unittests/test_config.py
@@ -1332,7 +1332,7 @@ def test_pdfpaint_has_expected_attributes_with_chunk(pdfpaint_dir_info):
assert len([line for line in manifest_lines if line]) == 100
assert test_config["tpcycles"] == 1
- assert test_config["tppagecycles"] == 5
+ assert test_config["tppagecycles"] == 15
assert test_config["tptimeout"] == 60000
assert test_config["gecko_profile_entries"] == 16777216
assert test_config["filters"] is not None
@@ -1378,7 +1378,7 @@ def test_pdfpaint_with_pdf_name(pdfpaint_dir_info):
assert manifest_lines[0].split("/")[-1] == "1"
assert test_config["tpcycles"] == 1
- assert test_config["tppagecycles"] == 5
+ assert test_config["tppagecycles"] == 15
@mock.patch("talos.config.get_browser_config")
diff --git a/testing/talos/talos/config.py b/testing/talos/talos/config.py
index 31162d692c..0287c8d971 100644
--- a/testing/talos/talos/config.py
+++ b/testing/talos/talos/config.py
@@ -264,11 +264,11 @@ def setup_pdfpaint_test(config, test_instance):
symlink_dest.symlink_to(pdfs_root, target_is_directory=True)
test_instance.tpmanifest = str(pdfpaint_manifest_path)
# Increase the pagecycles for each pdf to 5 if we're running chunks, otherwise
# it can take a very long time to complete testing of all pdfs
if chunk_number is not None or pdfpaint_test is not None:
- print("Setting pdfpaint tppagecycles to 5")
- test_instance.tppagecycles = 5
+ print("Setting pdfpaint tppagecycles to 15")
+ test_instance.tppagecycles = 15
def get_test_host(manifest_line):
@@ -264,11 +264,11 @@ def setup_pdfpaint_test(config, test_instance):
symlink_dest.symlink_to(pdfs_root, target_is_directory=True)
test_instance.tpmanifest = str(pdfpaint_manifest_path)
- # Increase the pagecycles for each pdf to 5 if we're running chunks, otherwise
+ # Increase the pagecycles for each pdf to 15 if we're running chunks, otherwise
# it can take a very long time to complete testing of all pdfs
if chunk_number is not None or pdfpaint_test is not None: